@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -26,9 +26,12 @@
 
 class QDomElement;
 
+namespace Analitza
+{
+
 /**
 *	The Cn class is the one that represents a value in the expression trees.
-*	@author Aleix Pol <aleixpol@gmail.com>
+*	@author Aleix Pol <aleixpol@kde.org>  
 */
 
 class ANALITZA_EXPORT Cn : public Object
@@ -152,6 +155,7 @@ class ANALITZA_EXPORT Cn : public Object
 		bool isCorrect() const { return m_type==Object::value; }
 		
 		virtual Object* copy() const;
+		virtual bool decorate(const QMap< QString, Object** >& scope);
 		
 		static Cn pi();
 		static Cn e();
@@ -161,4 +165,6 @@ class ANALITZA_EXPORT Cn : public Object
 		enum ValueFormat m_format;
 };
 
+}
+
 #endif
