@@ -46,6 +46,9 @@ namespace Avogadro {
   class ElementItem : public QObject, public QGraphicsItem
   {
     Q_OBJECT
+#if QT_VERSION >= 0x40600
+    Q_INTERFACES(QGraphicsItem)
+#endif
 
   public:
     /**
@@ -112,6 +115,9 @@ namespace Avogadro {
   class ElementDetail : public QObject, public QGraphicsItem
   {
     Q_OBJECT
+#if QT_VERSION >= 0x40600
+    Q_INTERFACES(QGraphicsItem)
+#endif
 
   public:
     /**
