@@ -80,14 +80,15 @@ class Kalzium : public KXmlGuiWindow
          */
         void setupSidebars();
 
-        //TODO KDE 4.1
-//        void extractIconicInformationAboutElement( int elementNumber );
+        void extractIconicInformationAboutElement( int elementNumber );
 
         /**
          * all KActions Kalzium uses
          */
-        KSelectAction *look_action;
-        KSelectAction *look_action_schemes;
+        KSelectAction *look_action_menu_schemes;
+        KSelectAction *look_action_menu_gradients;
+	KSelectAction *look_action_schemes;
+        KSelectAction *look_action_gradients;
 
         KSelectAction *table_action;
         KSelectAction *table_action_schemes;
@@ -97,6 +98,7 @@ class Kalzium : public KXmlGuiWindow
         QAction *m_SidebarAction;
         // tools
         QAction *m_pPlotAction;
+        QAction *m_pcalculator;
         QAction *m_pIsotopeTableAction;
         QAction *m_pGlossaryAction;
         QAction *m_pRSAction;
@@ -123,7 +125,7 @@ class Kalzium : public KXmlGuiWindow
         QDockWidget *m_dockWin;
         QDockWidget *m_InfoDock;
         QToolBox *m_toolbox;
-//X         KTabWidget *m_infoTabWidget;
+        KTabWidget *m_infoTabWidget;
 
         int m_toolboxCurrent;
 
@@ -170,7 +172,8 @@ class Kalzium : public KXmlGuiWindow
 
         void slotTables();
 
-        void slotSwitchtoLook( int );
+        void slotSwitchtoLookGradient( int );
+        void slotSwitchtoLookScheme( int );
         void slotSwitchtoNumeration(int);
 
         /**
@@ -178,7 +181,11 @@ class Kalzium : public KXmlGuiWindow
          */
         void slotIsotopeTable();
 
-        void slotPlotData();
+        void slotPlotData();	
+        /**
+         * Start the calculator
+         */
+        void showCalculator();
 
         void slotExportTable();
 
@@ -196,7 +203,6 @@ class Kalzium : public KXmlGuiWindow
         void slotShowHideSidebar( bool checked, bool changeconfig = true );
         void slotShowLegend( bool checked, bool changeconfig = true );
 
-
     protected:
         virtual void keyPressEvent( QKeyEvent * e);
 };
