@@ -30,11 +30,14 @@
 #include "../misc/calcpaths.h"
 #include "../misc/coordinate_system.h"
 
-#include "config.h"
+#include <config-kig.h>
 
+#include <qbytearray.h>
 #include <qdom.h>
 #include <qfile.h>
+#include <qfont.h>
 #include <qregexp.h>
+#include <qtextstream.h>
 
 #include <karchive.h>
 #include <kdebug.h>
@@ -105,16 +108,15 @@ bool KigFilterNative::supportMime( const QString& mime )
 KigDocument* KigFilterNative::load( const QString& file )
 {
   QFile ffile( file );
-  if ( ! ffile.open( IO_ReadOnly ) )
+  if ( ! ffile.open( QIODevice::ReadOnly ) )
   {
     fileNotFound( file );
     return 0;
   };
 
   QFile kigdoc( file );
-#ifndef KIG_NO_COMPRESSED_FILES
   bool iscompressed = false;
-  if ( !file.endsWith( ".kig", false ) )
+  if ( !file.endsWith( ".kig", Qt::CaseInsensitive ) )
   {
     // the file is compressed, so we have to decompress it and fetch the
     // kig file inside it...
@@ -125,7 +127,7 @@ KigDocument* KigFilterNative::load( const QString& file )
       KIG_FILTER_PARSE_ERROR;
 
     QString tempname = file.section( '/', -1 );
-    if ( file.endsWith( ".kigz", false ) )
+    if ( file.endsWith( ".kigz", Qt::CaseInsensitive ) )
     {
       tempname.remove( QRegExp( "\\.[Kk][Ii][Gg][Zz]$" ) );
     }
@@ -133,28 +135,27 @@ KigDocument* KigFilterNative::load( const QString& file )
       KIG_FILTER_PARSE_ERROR;
     // reading compressed file
     KTar* ark = new KTar( file, "application/x-gzip" );
-    ark->open( IO_ReadOnly );
+    ark->open( QIODevice::ReadOnly );
     const KArchiveDirectory* dir = ark->directory();
 //    assert( dir );
     QStringList entries = dir->entries();
-    QStringList kigfiles = entries.grep( QRegExp( "\\.kig$" ) );
+    QStringList kigfiles = entries.filter( QRegExp( "\\.kig$" ) );
     if ( kigfiles.count() != 1 )
       // I throw a generic parse error here, but I should warn the user that
       // this kig archive file doesn't contain one kig file (it contains no
       // kig files or more than one).
       KIG_FILTER_PARSE_ERROR;
-    const KArchiveEntry* kigz = dir->entry( kigfiles[0] );
+    const KArchiveEntry* kigz = dir->entry( kigfiles.at( 0 ) );
     if ( !kigz->isFile() )
       KIG_FILTER_PARSE_ERROR;
     dynamic_cast<const KArchiveFile*>( kigz )->copyTo( tempdir );
-    kdDebug() << "extracted file: " << tempdir + kigz->name() << endl
+    kDebug() << "extracted file: " << tempdir + kigz->name()
               << "exists: " << QFile::exists( tempdir + kigz->name() ) << endl;
 
-    kigdoc.setName( tempdir + kigz->name() );
+    kigdoc.setFileName( tempdir + kigz->name() );
   }
-#endif
 
-  if ( !kigdoc.open( IO_ReadOnly ) )
+  if ( !kigdoc.open( QIODevice::ReadOnly ) )
     KIG_FILTER_PARSE_ERROR;
 
   QDomDocument doc( "KigDocument" );
@@ -162,11 +163,9 @@ KigDocument* KigFilterNative::load( const QString& file )
     KIG_FILTER_PARSE_ERROR;
   kigdoc.close();
 
-#ifndef KIG_NO_COMPRESSED_FILES
   // removing temp file
   if ( iscompressed )
     kigdoc.remove();
-#endif
 
   QDomElement main = doc.documentElement();
 
@@ -193,7 +192,7 @@ KigDocument* KigFilterNative::load( const QString& file )
   if ( major > 0 || minor > 9 )
   {
     notSupported( file, i18n( "This file was created by Kig version \"%1\", "
-                              "which this version cannot open." ).arg( version ) );
+                              "which this version cannot open.", version ) );
     return false;
   }
   else if ( major == 0 && minor <= 3 )
@@ -204,7 +203,7 @@ KigDocument* KigFilterNative::load( const QString& file )
                               "You can try to open this file with an older Kig "
                               "version (0.4 to 0.6),\n"
                               "and then save it again, which will save it in the "
-                              "new format." ).arg( version ) );
+                              "new format.", version ) );
     return false;
   }
   else if ( major == 0 && minor <= 6 )
@@ -225,8 +224,8 @@ KigDocument* KigFilterNative::load04( const QString& file, const QDomElement& do
     if ( e.isNull() ) continue;
     if ( e.tagName() == "CoordinateSystem" )
     {
-      const QCString type = e.text().latin1();
-      CoordinateSystem* s = CoordinateSystemFactory::build( type );
+      const QByteArray type = e.text().toLatin1();
+      CoordinateSystem* s = CoordinateSystemFactory::build( type.data() );
       if ( ! s )
       {
         warning( i18n( "This Kig file has a coordinate system "
@@ -307,22 +306,22 @@ KigDocument* KigFilterNative::load04( const QString& file, const QDomElement& do
         }
         else if ( e.tagName() == "Property" )
         {
-          QCString propname;
+          QByteArray propname;
           for ( QDomElement ec = e.firstChild().toElement(); !ec.isNull();
                 ec = ec.nextSibling().toElement() )
           {
             if ( ec.tagName() == "Property" )
-              propname = ec.text().latin1();
+              propname = ec.text().toLatin1();
           };
 
           if ( i->parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
           ObjectCalcer* parent = retcalcers[i->parents[0] -1];
-          QCStringList propnames = parent->imp()->propertiesInternalNames();
-          int propid = propnames.findIndex( propname );
+          QByteArrayList propnames = parent->imp()->propertiesInternalNames();
+          int propid = propnames.indexOf( propname );
           if ( propid == -1 )
             KIG_FILTER_PARSE_ERROR;
 
-          o = new ObjectPropertyCalcer( parent, propid );
+          o = new ObjectPropertyCalcer( parent, propname );
         }
         else if ( e.tagName() == "Object" )
         {
@@ -331,14 +330,14 @@ KigDocument* KigFilterNative::load04( const QString& file, const QDomElement& do
             KIG_FILTER_PARSE_ERROR;
 
           const ObjectType* type =
-            ObjectTypeFactory::instance()->find( tmp.latin1() );
+            ObjectTypeFactory::instance()->find( tmp.toLatin1() );
           if ( !type )
           {
             notSupported( file, i18n( "This Kig file uses an object of type \"%1\", "
                                       "which this Kig version does not support."
                                       "Perhaps you have compiled Kig without support "
                                       "for this object type,"
-                                      "or perhaps you are using an older Kig version." ).arg( tmp ) );
+                                      "or perhaps you are using an older Kig version.", tmp ) );
             return false;
           };
 
@@ -386,6 +385,11 @@ KigFilterNative* KigFilterNative::instance()
   return &f;
 }
 
+static const char* obsoletemessage = I18N_NOOP(
+                           "This Kig file uses an object of type \"%1\", "
+                           "which is obsolete, you should save the construction with "
+                           "a different name and check that it works as expected." );
+
 KigDocument* KigFilterNative::load07( const QString& file, const QDomElement& docelem )
 {
   KigDocument* ret = new KigDocument();
@@ -414,8 +418,8 @@ KigDocument* KigFilterNative::load07( const QString& file, const QDomElement& do
         ret->setGrid( false );
         ret->setAxes( false );
       }
-      const QCString type = tmptype.latin1();
-      CoordinateSystem* s = CoordinateSystemFactory::build( type );
+      const QByteArray type = tmptype.toLatin1();
+      CoordinateSystem* s = CoordinateSystemFactory::build( type.data() );
       if ( ! s )
       {
         warning( i18n( "This Kig file has a coordinate system "
@@ -466,27 +470,69 @@ KigDocument* KigFilterNative::load07( const QString& file, const QDomElement& do
         else if ( e.tagName() == "Property" )
         {
           if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
-          QCString propname = e.attribute( "which" ).latin1();
+          QByteArray propname = e.attribute( "which" ).toLatin1();
 
           ObjectCalcer* parent = parents[0];
-          int propid = parent->imp()->propertiesInternalNames().findIndex( propname );
+          int propid = parent->imp()->propertiesInternalNames().indexOf( propname );
           if ( propid == -1 ) KIG_FILTER_PARSE_ERROR;
 
-          o = new ObjectPropertyCalcer( parent, propid );
+          o = new ObjectPropertyCalcer( parent, propname );
         }
         else if ( e.tagName() == "Object" )
         {
           QString tmp = e.attribute( "type" );
           const ObjectType* type =
-            ObjectTypeFactory::instance()->find( tmp.latin1() );
+            ObjectTypeFactory::instance()->find( tmp.toLatin1() );
           if ( ! type )
           {
-            notSupported( file, i18n( "This Kig file uses an object of type \"%1\", "
-                                      "which this Kig version does not support."
-                                      "Perhaps you have compiled Kig without support "
-                                      "for this object type,"
-                                      "or perhaps you are using an older Kig version." ).arg( tmp ) );
-            return false;
+            if ( tmp == "MeasureTransport" && parents.size() == 3 )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "TransportOfMeasure" );
+              ObjectCalcer* circle = parents[0];
+              ObjectCalcer* point = parents[1];
+              ObjectCalcer* segment = parents[2];
+              parents[0] = segment;
+              parents[1] = circle;
+              parents[2] = point;
+            } else if ( tmp == "InvertLine" )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "CircularInversion" );
+            } else if ( tmp == "InvertSegment" )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "CircularInversion" );
+            } else if ( tmp == "InvertCircle" )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "CircularInversion" );
+            } else if ( tmp == "InvertArc" )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "CircularInversion" );
+            } else if ( tmp == "ConicArcBTPC" )
+            {
+              warning( i18n( obsoletemessage, tmp ) );
+              type = ObjectTypeFactory::instance()->find( "ConicArcBCTP" );
+              //
+              // the only difference is in the order of parents
+              // entering the center first seems more useful, and allows
+              // for a better user interface
+              //
+              ObjectCalcer* point = parents[3];
+              parents[3] = parents[2];
+              parents[2] = parents[1];
+              parents[1] = parents[0];
+              parents[0] = point;
+            } else {
+              notSupported( file, i18n( "This Kig file uses an object of type \"%1\", "
+                                        "which this Kig version does not support."
+                                        "Perhaps you have compiled Kig without support "
+                                        "for this object type,"
+                                        "or perhaps you are using an older Kig version.", tmp ) );
+              return false;
+            }
           }
 
 	  // mp: (I take the responsibility for this!) explanation: the usual ObjectTypeCalcer
@@ -541,20 +587,25 @@ KigDocument* KigFilterNative::load07( const QString& file, const QDomElement& do
         tmp = e.attribute( "point-style" );
         int pointstyle = ObjectDrawer::pointStyleFromString( tmp );
 
+        tmp = e.attribute( "font" );
+        QFont f;
+        if ( !tmp.isEmpty() )
+          f.fromString( tmp );
+
         ObjectConstCalcer* namecalcer = 0;
         tmp = e.attribute( "namecalcer" );
         if ( tmp != "none" && !tmp.isEmpty() )
         {
           int ncid = tmp.toInt( &ok );
           if ( !ok ) KIG_FILTER_PARSE_ERROR;
-          if ( ncid <= 0 || ncid > calcers.size() )
+          if ( ncid <= 0 || ncid > static_cast<int>( calcers.size() ) )
             KIG_FILTER_PARSE_ERROR;
           if ( ! dynamic_cast<ObjectConstCalcer*>( calcers[ncid-1].get() ) )
             KIG_FILTER_PARSE_ERROR;
           namecalcer = static_cast<ObjectConstCalcer*>( calcers[ncid-1].get() );
         }
 
-        ObjectDrawer* drawer = new ObjectDrawer( color, width, shown, style, pointstyle );
+        ObjectDrawer* drawer = new ObjectDrawer( color, width, shown, style, pointstyle, f );
         holders.push_back( new ObjectHolder( calcer, drawer, namecalcer ) );
       }
     }
@@ -568,6 +619,10 @@ bool KigFilterNative::save07( const KigDocument& kdoc, QTextStream& stream )
 {
   QDomDocument doc( "KigDocument" );
 
+  QDomProcessingInstruction xmlpi = doc.createProcessingInstruction(
+          QString::fromLatin1( "xml" ), QString::fromLatin1( "version=\"1.0\" encoding=\"utf-8\"" ) );
+  doc.appendChild( xmlpi );
+
   QDomElement docelem = doc.createElement( "KigDocument" );
   docelem.setAttribute( "Version", KIGVERSION );
   docelem.setAttribute( "CompatibilityVersion", "0.7.0" );
@@ -604,8 +659,8 @@ bool KigFilterNative::save07( const KigDocument& kdoc, QTextStream& stream )
       const ObjectPropertyCalcer* o = static_cast<const ObjectPropertyCalcer*>( *i );
       objectelem = doc.createElement( "Property" );
 
-      QCString propname = o->parent()->imp()->propertiesInternalNames()[o->propId()];
-      objectelem.setAttribute( "which", propname );
+      QByteArray propname = o->parent()->imp()->getPropName( o->propGid() );
+      objectelem.setAttribute( "which", QString( propname ) );
     }
     else if ( dynamic_cast<const ObjectTypeCalcer*>( *i ) )
     {
@@ -642,10 +697,11 @@ bool KigFilterNative::save07( const KigDocument& kdoc, QTextStream& stream )
     QDomElement drawelem = doc.createElement( "Draw" );
     drawelem.setAttribute( "object", id );
     drawelem.setAttribute( "color", d->color().name() );
-    drawelem.setAttribute( "shown", QString::fromLatin1( d->shown() ? "true" : "false" ) );
+    drawelem.setAttribute( "shown", QLatin1String( d->shown() ? "true" : "false" ) );
     drawelem.setAttribute( "width", QString::number( d->width() ) );
     drawelem.setAttribute( "style", d->styleToString() );
     drawelem.setAttribute( "point-style", d->pointStyleToString() );
+    drawelem.setAttribute( "font", d->font().toString() );
 
     ObjectCalcer* namecalcer = ( *i )->nameCalcer();
     if ( namecalcer )
@@ -679,11 +735,11 @@ bool KigFilterNative::save07( const KigDocument& data, const QString& outfile )
   // we have an empty outfile, so we have to print all to stdout
   if ( outfile.isEmpty() )
   {
-    QTextStream stdoutstream( stdout, IO_WriteOnly );
+    QTextStream stdoutstream( stdout, QIODevice::WriteOnly );
+    stdoutstream.setCodec( "UTF-8" );
     return save07( data, stdoutstream );
   }
-#ifndef KIG_NO_COMPRESSED_FILES
-  if ( !outfile.endsWith( ".kig", false ) )
+  if ( !outfile.endsWith( ".kig", Qt::CaseInsensitive ) )
   {
     // the user wants to save a compressed file, so we have to save our kig
     // file to a temp file and then compress it...
@@ -693,25 +749,26 @@ bool KigFilterNative::save07( const KigDocument& data, const QString& outfile )
       return false;
 
     QString tempname = outfile.section( '/', -1 );
-    if ( outfile.endsWith( ".kigz", false ) )
+    if ( outfile.endsWith( ".kigz", Qt::CaseInsensitive ) )
       tempname.remove( QRegExp( "\\.[Kk][Ii][Gg][Zz]$" ) );
     else
       return false;
 
     QString tmpfile = tempdir + tempname + ".kig";
     QFile ftmpfile( tmpfile );
-    if ( !ftmpfile.open( IO_WriteOnly ) )
+    if ( !ftmpfile.open( QIODevice::WriteOnly ) )
       return false;
     QTextStream stream( &ftmpfile );
+    stream.setCodec( "UTF-8" );
     if ( !save07( data, stream ) )
       return false;
     ftmpfile.close();
 
-    kdDebug() << "tmp saved file: " << tmpfile << endl;
+    kDebug() << "tmp saved file: " << tmpfile;
 
     // creating the archive and adding our file
     KTar* ark = new KTar( outfile,  "application/x-gzip" );
-    ark->open( IO_WriteOnly );
+    ark->open( QIODevice::WriteOnly );
     ark->addLocalFile( tmpfile, tempname + ".kig" );
     ark->close();
 
@@ -722,21 +779,19 @@ bool KigFilterNative::save07( const KigDocument& data, const QString& outfile )
   }
   else
   {
-#endif
     QFile file( outfile );
-    if ( ! file.open( IO_WriteOnly ) )
+    if ( ! file.open( QIODevice::WriteOnly ) )
     {
       fileNotFound( outfile );
       return false;
     }
     QTextStream stream( &file );
+    stream.setCodec( "UTF-8" );
     return save07( data, stream );
-#ifndef KIG_NO_COMPRESSED_FILES
   }
 
   // we should never reach this point...
   return false;
-#endif
 }
 
 /*
