@@ -1,8 +1,8 @@
 /*
 * KmPlot - a math. function plotter for the KDE-Desktop
 *
-* Copyright (C) 2004  Fredrik Edemar
-*                     f_edemar@linux.se
+* Copyright (C) 2004  Fredrik Edemar <f_edemar@linux.se>
+*               2006  David Saxton <david@bluehaze.org>
 *               
 * This file is part of the KDE Project.
 * KmPlot is part of the KDE-EDU Project.
@@ -26,37 +26,60 @@
 #ifndef KPARAMETEREDITOR_H
 #define KPARAMETEREDITOR_H
 
-#include "qparametereditor.h"
+#include "ui_qparametereditor.h"
+#include <QList>
 #include "xparser.h"
 
-class ParameterValueList;
+#include <kdialog.h>
+
+class QParameterEditor;
 
 /**
 @author Fredrik Edemar
 */
 /// This class handles the parameter values: it can create, remove, edit and import values.
-class KParameterEditor : public QParameterEditor
+class KParameterEditor : public KDialog
 {
 Q_OBJECT
 public:
-    KParameterEditor(XParser *, QValueList<ParameterValueItem> *, QWidget *parent = 0, const char *name = 0);
+	KParameterEditor( QList<Value> *, QWidget *parent );
     ~KParameterEditor();
     
 public slots:
+	void moveUp();
+	void moveDown();
+	void prev();
+	void next();
     void cmdNew_clicked();
-    void cmdEdit_clicked();
     void cmdDelete_clicked();
     void cmdImport_clicked();
     void cmdExport_clicked();
-    void varlist_clicked( QListBoxItem *  );
-    void varlist_doubleClicked( QListBoxItem * );
+    
+    ///actions for the visible constant list
+	void selectedConstantChanged( QListWidgetItem * current );
+	
+	/// updates whether or not the "value is invalid" label is shown, (and returns the validity of the current value)
+	bool checkValueValid();
+	
+	/// saves the value being edited
+	void saveCurrentValue();
+	
+	virtual void accept();
   
     
 private:
     /// Check so that it doesn't exist two equal values
     bool checkTwoOfIt( const QString & text);
-    QValueList<ParameterValueItem> *m_parameter;
-    XParser *m_parser;
+    QList<Value> *m_parameter;
+	QParameterEditor * m_mainWidget;
+};
+
+class QParameterEditor : public QWidget, public Ui::QParameterEditor
+{
+	public:
+		QParameterEditor( QWidget * parent = 0 )
+	: QWidget( parent )
+		{ setupUi(this); }
 };
 
 #endif
