@@ -91,7 +91,8 @@ public:
                 double par=0.0, bool mult=false, bool var=false, int hd=0 );
 
     virtual StarObject* clone() const;
-    
+    virtual UID getUID() const;
+   
     /** Copy constructor */
     StarObject(const StarObject& o);
 
@@ -110,7 +111,6 @@ public:
      *@param  stardata  Pointer to starData object containing required data (except name and gname)
      *@return Nothing
      */
-
     void init( const starData *stardata );
     
     /**
@@ -119,7 +119,6 @@ public:
      *@param  stardata  Pointer to deepStarData object containing the available data
      *@return Nothing
      */
-
     void init( const deepStarData *stardata );
 
     /**
@@ -128,7 +127,6 @@ public:
      *@param  name  Common name
      *@param  name2 Genetive name
      */
-
     void setNames( QString name, QString name2 );
 
     /**
@@ -145,10 +143,6 @@ public:
         *If star is unnamed return "star" otherwise return the longname
         */
     inline virtual QString longname( void ) const { return hasLongName() ? LongName : starString; }
-    /**
-        *@return QColor corresponding to the star's Spectral Type
-        */
-    QColor color( void ) const;
 
     /**
         *Returns entire spectral type string
@@ -248,28 +242,6 @@ public:
         */
     inline bool isVariable() const { return Variability; }
 
-    /**@return true if the passed character is a valid spectral class
-     */
-    bool isSpecType( char c );
-
-    //Not using VRange, VPeriod currently (to save memory)
-    ///**@short set the range in brightness covered by the star's variability
-    //  *@param r the range of brightness, in magnitudes
-    //  */
-    //  void setVRange( double r ) { VRange = r; }
-    //
-    ///**@return the range in brightness covered by the star's variability, in magnitudes
-    //  */
-    //  double vrange() const { return VRange; }
-    //
-    ///**@short set the period of the star's brightness variation, in days.
-    //  */
-    //  void setVPeriod( double p ) { VPeriod = p; }
-    //
-    ///**@return the period of the star's brightness variation, in days.
-    //  */
-    //  double vperiod() const { return VPeriod; }
-
     void draw( QPainter &psky, float x, float y, float size,
                bool useRealColors, int scIntensity, bool drawMultiple=true );
 
@@ -297,46 +269,13 @@ public:
         */
     virtual void showPopupMenu( KSPopupMenu *pmenu, const QPoint &pos );
 
-    /**
-        *Reet the colors which will be used to make realistic star colors.
-        *Each star has a spectral type, a string whose first letter indicates 
-        *its color (RGB triplets shown below):
-        *@li O: (   0,   0, 255 )
-        *@li B: (   0, 200, 255 )
-        *@li A: (   0, 255, 255 )
-        *@li F: ( 200, 255, 100 )
-        *@li G: ( 255, 255,   0 )
-        *@li K: ( 255, 100,   0 )
-        *@li M: ( 255,   0,   0 )
-        *
-        *If the user has enabled antialiased drawing, then these are the RGB 
-        *codes of the colors that will be assigned to each spectral type.
-        *However, if antialiasing is disabled, it is more complicated, because 
-        *the colored "rim" of the star image cannot be less than 1 pixel wide,
-        *so the above RGB codes will produce very saturated star colors.
-        *To fix this, we mix the above colors with white to desaturate the 
-        *colors, effectively simulating an antialiased colored band with width 
-        *less than 1 pixel.
-        *
-        *@note This function only needs to be called when the user modifies the 
-        *star color saturation level, or when the user toggles 
-        *Options::useAntialias().
-        *
-        *@param desaturateColors if true, then we need to desaturate the star colors.
-        *@param saturation The saturation level for star colors (this will 
-        *almost always be passed as data()->colorScheme()->starColorIntensity())
-        */
-    static void updateColors( bool desaturateColors, int saturation );
-
+    /** Create cached images for stars rendering. */
     static void initImages();
 
     quint64 updateID;
     quint64 updateNumID;
 
 protected:
-    static QMap<QString, QColor> ColorMap;
-    static QHash<QString, QPixmap> StarImage;
-
     // DEBUG EDIT. For testing proper motion, uncomment this, and related blocks
     // See starobject.cpp for further info.
     //    static QVector<SkyPoint *> Trail;
