@@ -89,27 +89,44 @@ void dmsBox::slotTextChanged( const QString &t ) {
 
 void dmsBox::setDegType( bool t ) {
     deg = t;
-    QString sDeg = ( t ? i18n( "degrees" ) : i18n( "hours" ) );
-    QString sMin = ( t ? i18n( "arcminutes" ) : i18n( "minutes" ) );
-    QString sSec = ( t ? i18n( "arcseconds" ) : i18n( "seconds" ) );
 
-    QString sTip = i18n( "Angle value in %1.", sDeg );
+    QString sTip = ( t ? i18n( "Angle value in degrees." ) : i18n( "Angle value in hours." ) );
     QString sWhatsThis;
 
     if ( isReadOnly() ) {
-        sWhatsThis = i18n( "This box displays an angle in %1. "
-                           "The three numbers displayed are the angle's "
-                           "%1, %2, and %3." , sDeg, sMin, sSec);
+        if( t ) {
+            sWhatsThis = i18n( "This box displays an angle in degrees. "
+                               "The three numbers displayed are the angle's "
+                               "degrees, arcminutes, and arcseconds." );
+        }
+        else {
+            sWhatsThis = i18n( "This box displays an angle in hours. "
+                               "The three numbers displayed are the angle's "
+                               "hours, minutes, and seconds." );
+        }
     } else {
-        sTip += i18n( "  You may enter a simple integer, or a floating-point value, "
-                      "or space- or colon-delimited values specifying "
-                      "%1, %2 and %3" , sDeg, sMin, sSec);
+        if( t ) {
+            sTip += i18n( "  You may enter a simple integer, or a floating-point value, "
+                          "or space- or colon-delimited values specifying "
+                          "degrees, arcminutes and arcseconds" );
 
-        sWhatsThis = i18n( "Enter an angle value in %1.  The angle can be expressed "
-                           "as a simple integer (\"12\"), or floating-point "
-                           "(\"12.33\") value, or as space- or colon-delimited "
-                           "values specifying %1, %2 and %3 (\"12:20\", \"12:20:00\", "
-                           "\"12 20\", \"12 20 00.0\", etc.)." , sDeg, sMin, sSec);
+            sWhatsThis = i18n( "Enter an angle value in degrees.  The angle can be expressed "
+                               "as a simple integer (\"12\"), a floating-point value "
+                               "(\"12.33\"), or as space- or colon-delimited "
+                               "values specifying degrees, arcminutes and arcseconds (\"12:20\", \"12:20:00\", "
+                               "\"12 20\", \"12 20 00.0\", etc.)." );
+        }
+        else {
+            sTip += i18n( "  You may enter a simple integer, or a floating-point value, "
+                          "or space- or colon-delimited values specifying "
+                          "hours, minutes and seconds" );
+            
+            sWhatsThis = i18n( "Enter an angle value in hours.  The angle can be expressed "
+                               "as a simple integer (\"12\"), a floating-point value "
+                               "(\"12.33\"), or as space- or colon-delimited "
+                               "values specifying hours, minutes and seconds (\"12:20\", \"12:20:00\", "
+                               "\"12 20\", \"12 20 00.0\", etc.)." );
+        }
     }
 
     setToolTip( sTip );
