@@ -585,6 +585,10 @@ void KWordQuizApp::openDocumentFile(const KUrl& url)
   if (!url.isEmpty() && KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this)) {
     int result = m_doc->open(url);
     if (result == KEduVocDocument::NoError) {
+      while (m_doc->identifierCount() < 2) { //if we opened a TAB-less CSV, there
+        m_doc->appendIdentifier(); //may be 0 or 1 identifiers, we need at least 2  
+      }
+ 
       m_tableModel->reset();
       m_dirWatch->addFile(url.path());
       setCaption(m_doc->url().fileName(), false);
@@ -740,7 +744,7 @@ void KWordQuizApp::slotFileOpen()
   cb -> setEnabled(false);
 
   QString filter = KEduVocDocument::pattern(KEduVocDocument::Reading);
-  KFileDialog *fd = new KFileDialog(KUrl(), filter, this, cb);
+  QPointer<KFileDialog> fd = new KFileDialog(KUrl(), filter, this, cb);
   fd->setOperationMode(KFileDialog::Opening);
   fd->setMode(KFile::Files | KFile::ExistingOnly);
   fd->setCaption(i18n("Open Vocabulary Document"));
@@ -842,7 +846,7 @@ bool KWordQuizApp::saveDocAsFileName(KEduVocDocument *document)
   bool success = false;
 
   QString filter = KEduVocDocument::pattern(KEduVocDocument::Writing);
-  KFileDialog *fd = new KFileDialog(KUrl(), filter, this);
+  QPointer<KFileDialog> fd = new KFileDialog(KUrl(), filter, this);
   fd->setOperationMode(KFileDialog::Saving);
   fd->setCaption(i18n("Save Vocabulary Document As"));
   fd->setConfirmOverwrite(true);
