@@ -5,12 +5,12 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 //
-// MarblePlacemarkModel resembles the model for Placemarks
+// MarblePlacemarkModel exposes the model for Placemarks
 //
 
 
@@ -25,14 +25,13 @@
 
 #include "marble_export.h"
 
+#include "GeoDataPlacemark.h"
+
 namespace Marble
 {
 
 class GeoDataCoordinates;
 class GeoDataStyle;
-class PlacemarkContainer;
-class PlacemarkManager;
-
 /**
  * This class represents a model of all place marks which
  * are currently available through a given PlacemarkManager.
@@ -65,26 +64,23 @@ class MARBLE_EXPORT MarblePlacemarkModel : public QAbstractListModel
     /**
      * Creates a new place mark model.
      *
-     * @param manager The place mark manager on which the model shall work.
      * @param parent The parent object.
      */
-    explicit MarblePlacemarkModel( PlacemarkManager *manager, 
-                                   QObject *parent = 0 );
+    explicit MarblePlacemarkModel( QObject *parent = 0 );
 
     /**
      * Destroys the place mark model.
      */
     ~MarblePlacemarkModel();
-	
+
+    void setPlacemarkContainer( QVector<Marble::GeoDataPlacemark> *container );
+
     /**
      * Return the number of Placemarks in the Model.
      */
     int rowCount( const QModelIndex &parent = QModelIndex() ) const;
     int columnCount( const QModelIndex &parent = QModelIndex() ) const;
 
-    Marble::GeoDataCoordinates coordinateData( const QModelIndex &index ) const;
-    Marble::GeoDataStyle* styleData( const QModelIndex &index ) const;
-
     /**
      * Return the data according to the index.
      *
@@ -100,55 +96,23 @@ class MARBLE_EXPORT MarblePlacemarkModel : public QAbstractListModel
     /**
      * This method is used by the PlacemarkManager to add new
      * place marks to the model.
-     *
-     * Note: The model takes ownership of the place marks!
      */
-    void addPlacemarks( PlacemarkContainer &placemarks, 
-                        bool clearPrevious = false,
-                        bool finalize = true );
+    void addPlacemarks( int start,
+                        int length );
 
     /**
      * This method is used by the PlacemarkManager to remove
      * place marks from the model.
-     *
-     * Note: The model takes ownership of the place marks!
      */
     void removePlacemarks( const QString &containerName,
                            int start,
-                           int length,
-                           bool finalize = true );
-
-    /**
-    * This method returns a list of open Containers (== open kml files)
-    */
-    QStringList containers() const;
-
- Q_SIGNALS:
-    /**
-     * @brief Signal that the persistant Index has been updated
-     */
-    void indexUpdated();
+                           int length );
 
  private:
 
-    /**
-     * This method is used by the PlacemarkManager to clear
-     * the model.
-     */
-    void clearPlacemarks();
-    
-    virtual void sort( int column, Qt::SortOrder order = Qt::AscendingOrder );
-
-    void createFilterProperties( PlacemarkContainer &container );
-
     Q_DISABLE_COPY( MarblePlacemarkModel )
     class Private;
     Private* const d;
-
- protected:
-    int cityPopIdx( qint64 population ) const;
-    int spacePopIdx( qint64 diameter ) const;
-    int areaPopIdx( qreal area ) const;
 };
 
 }
