@@ -24,6 +24,7 @@
 #include <QtCore/QObject>
 #include <QtCore/QVector>
 #include <QtCore/QString>
+#include <QtCore/QMutex>
 
 namespace Marble
 {
@@ -40,12 +41,11 @@ public:
     explicit MarbleRunnerManager( QObject *parent = 0 );
     ~MarbleRunnerManager();
     
-    void setModel(MarblePlacemarkModel *model);
-    MarblePlacemarkModel* model();
+    void setCelestialBodyId(const QString &celestialBodyId);
+
 public slots:
     void newText(QString text);
 signals:
-    void allDone();
     void modelChanged( MarblePlacemarkModel *model );
 
 private slots:
@@ -56,7 +56,9 @@ private:
     QString m_lastString;
     MarblePlacemarkModel *m_model;
     QList<MarbleAbstractRunner*> m_runners;
-    
+    QVector<GeoDataPlacemark> m_placemarkContainer;
+    QMutex m_modelMutex;
+    QString m_celestialBodyId;
 };
 
 }
