@@ -5,15 +5,15 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "MarbleSearchListView.h"
 
 #include "MarblePlacemarkModel.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 #include <QtGui/QStandardItemModel>
 
 using namespace Marble;
