@@ -19,7 +19,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 #include <QtCore/QFile>
 #include <QtCore/QStringList>
 #include <QtGui/QApplication>
@@ -28,6 +28,7 @@
 #include "GeoDataDocument.h"
 #include "GeoDataFolder.h"
 #include "GeoDataPlacemark.h"
+#include "GeoDataLookAt.h"
 
 #include "GeoSceneDocument.h"
 #include "GeoSceneHead.h"
@@ -41,7 +42,7 @@
 
 #ifdef Q_OS_WIN
 #include <stdio.h>
-#include <stdlib.h>
+#include <cstdlib>
 
 void myMessageOutput(QtMsgType type, const char *msg)
 {
@@ -190,7 +191,8 @@ QString formatOutput(int depth)
 
 void dumpGeoDataPlacemark(const GeoDataPlacemark& placemark)
 {
-    qDebug() << placemark.name() << placemark.population() << placemark.coordinate().toString();
+    Q_UNUSED(placemark);
+//	qDebug() << placemark.name() << placemark.population() << placemark.coordinate().toString()<<"lookAt info "<<(placemark.lookAt()->coordinate())->toString()<<placemark.lookAt()->altitude();
 }
 
 void dumpFoldersRecursively(const GeoDataContainer& container, int depth)
