@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlPenTagHandler : public GeoTagHandler {
-public:
-    DgmlPenTagHandler();
-    virtual ~DgmlPenTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlPenTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlPenTagHandler_h
