@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlTextTagHandler : public GeoTagHandler {
-public:
-    DgmlTextTagHandler();
-    virtual ~DgmlTextTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlTextTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlTextTagHandler_h
