@@ -21,10 +21,12 @@
 
 #include "GPXgpxTagHandler.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 #include "GPXElementDictionary.h"
-#include "GeoParser.h"
+#include "GeoDataParser.h"
+
+#include "GeoDataDocument.h"
 
 namespace Marble
 {
@@ -34,11 +36,11 @@ GPX_DEFINE_TAG_HANDLER(gpx)
 
 GeoNode* GPXgpxTagHandler::parse(GeoParser& parser) const
 {
-    Q_UNUSED(parser); // Don't complain when asserts are turned off
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(gpxTag_gpx));
-
-    qDebug() << "Parsed <Document> start!";    
-    return 0;
+    GeoDataDocument* doc = geoDataDoc( parser );
+//#ifdef DEBUG_TAGS
+    mDebug() << "Parsed <" << gpxTag_gpx << "> document: " << doc;
+//#endif
+    return doc;
 }
 
 }
