@@ -22,7 +22,7 @@
 #if KML_LAZY_IMP
 #include "KmlCountrycodeTagHandler.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 #include "KmlElementDictionary.h"
 
@@ -46,7 +46,7 @@ GeoNode* KmlcountrycodeTagHandler::parse( GeoParser& parser ) const
         
         parentItem.nodeAs<GeoDataPlacemark>()->setCountryCode( countrycode );
 #ifdef DEBUG_TAGS
-        qDebug() << "Parsed <" << kmlTag_countrycode << "> containing: " << countrycode
+        mDebug() << "Parsed <" << kmlTag_countrycode << "> containing: " << countrycode
                  << " parent item name: " << parentItem.qualifiedName().first;
 #endif // DEBUG_TAGS
     }
