@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlFolderTagHandler : public GeoTagHandler {
-public:
-    KmlFolderTagHandler();
-    virtual ~KmlFolderTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlFolderTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlFolderTagHandler_h
