@@ -21,16 +21,17 @@
 
 #include "GeoSceneIcon.h"
 
+namespace Marble
+{
+
 GeoSceneIcon::GeoSceneIcon()
     : m_pixmap( "" ),
       m_color( "" )
 {
-    /* NOOP */
 }
 
 GeoSceneIcon::~GeoSceneIcon()
 {
-    /* NOOP */
 }
 
 QString GeoSceneIcon::pixmap() const
@@ -52,3 +53,5 @@ void GeoSceneIcon::setColor( const QColor& color )
 {
     m_color = color;
 }
+
+}
