@@ -10,12 +10,10 @@
 
 #include "QNamDownloadJob.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 #include <QtNetwork/QNetworkAccessManager>
 #include <QtNetwork/QNetworkRequest>
 
-#include "global.h"
-
 namespace Marble
 {
 
@@ -32,7 +30,7 @@ QNamDownloadJob::QNamDownloadJob( const QUrl & sourceUrl,
 void QNamDownloadJob::execute()
 {
     QNetworkRequest request( sourceUrl() );
-    request.setRawHeader( "User-Agent", getUserAgent().toLatin1() );
+    request.setRawHeader( "User-Agent", "Marble TinyWebBrowser" );
     m_networkReply = m_networkAccessManager->get( request );
 
     connect( m_networkReply, SIGNAL( downloadProgress( qint64, qint64 )),
@@ -45,19 +43,21 @@ void QNamDownloadJob::execute()
 
 void QNamDownloadJob::downloadProgress( qint64 bytesReceived, qint64 bytesTotal )
 {
-//     qDebug() << "downloadProgress" << destinationFileName()
+    Q_UNUSED(bytesReceived);
+    Q_UNUSED(bytesTotal);
+//     mDebug() << "downloadProgress" << destinationFileName()
 //              << bytesReceived << '/' << bytesTotal;
 }
 
 void QNamDownloadJob::error( QNetworkReply::NetworkError code )
 {
-    qDebug() << "error" << destinationFileName() << code;
+    mDebug() << "error" << destinationFileName() << code;
 }
 
 void QNamDownloadJob::finished()
 {
     QNetworkReply::NetworkError const error = m_networkReply->error();
-//     qDebug() << "finished" << destinationFileName()
+//     mDebug() << "finished" << destinationFileName()
 //              << "error" << error;
 
     switch ( error ) {
@@ -81,19 +81,11 @@ void QNamDownloadJob::finished()
     }
 
     m_networkReply->disconnect( this );
-
     // No delete. This method is called by a signal QNetworkReply::finished.
     m_networkReply->deleteLater();
     m_networkReply = 0;
 }
 
-QString QNamDownloadJob::getUserAgent() const
-{
-    QString userAgent = QString( "Mozilla/5.0 (compatible; Marble/%1; Viewer; QNamNetworkPlugin)" )
-        .arg( MARBLE_VERSION_STRING );
-    return userAgent;
-}
-
 }
 
 #include "QNamDownloadJob.moc"
