@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008 Shashank Singh <shashank.personal@gmail.com>"
+// Copyright 2008 Shashank Singh <shashank.personal@gmail.com>
 // C++ Interface: imagewidget
 //
 #ifndef IMAGEWIDGET_H
@@ -18,7 +18,8 @@ This class implements a Widget that shows image in thumbnail format and then it
 
 	@author Shashank Singh <shashank.singh@geodesic.com>
 */
-class imageWidget : public QWidget {
+class imageWidget : public QWidget
+{
     Q_OBJECT
     Q_DISABLE_COPY(imageWidget) //i am trying to save this class from deepcopy
 public:
